@@ -1,5 +1,5 @@
-#ifndef _ABOUT_H__
-#define _ABOUT_H__ 1
+#ifndef TERMINOLOGY_ABOUT_H_
+#define TERMINOLOGY_ABOUT_H_ 1
 
 void about_show(Evas_Object *win, Evas_Object *base, Evas_Object *term,
                   void (*donecb) (void *data), void *donedata);
