@@ -1,5 +1,5 @@
-#ifndef _CONTROLS_H__
-#define _CONTROLS_H__ 1
+#ifndef TERMINOLOGY_CONTROLS_H_
+#define TERMINOLOGY_CONTROLS_H_ 1
 
 void controls_show(Evas_Object *win, Evas_Object *base, Evas_Object *bg,
                    Evas_Object *term,
