@@ -1,11 +1,11 @@
-#ifndef _IPC_H__
-#define _IPC_H__ 1
+#ifndef TERMINOLOGY_IPC_H_
+#define TERMINOLOGY_IPC_H_ 1
 
 #include "config.h"
 
-typedef struct _Ipc_Instance Ipc_Instance;
+typedef struct tag_Ipc_Instance Ipc_Instance;
 
-struct _Ipc_Instance
+struct tag_Ipc_Instance
 {
    char *cmd;
    char *cd;
