@@ -1,5 +1,5 @@
-#ifndef _MEDIA_H__
-#define _MEDIA_H__ 1
+#ifndef TERMINOLOGY_MEDIA_H_
+#define TERMINOLOGY_MEDIA_H_ 1
 
 #define MEDIA_SIZE_MASK    0x000f
 #define MEDIA_OPTIONS_MASK 0x00f0
@@ -14,10 +14,11 @@
 #define MEDIA_SAVE         0x0020
 
 
-typedef enum _Media_Type Media_Type;
+typedef enum tag_Media_Type Media_Type;
 
-enum _Media_Type {
+enum tag_Media_Type {
      MEDIA_TYPE_UNKNOWN,
+     MEDIA_TYPE_RECT,
      MEDIA_TYPE_IMG,
      MEDIA_TYPE_SCALE,
      MEDIA_TYPE_EDJE,
