@@ -12,7 +12,7 @@
 #include "main.h"
 #include <sys/stat.h>
 
-typedef struct _Background_Ctx {
+typedef struct tag_Background_Ctx {
      Config *config;
      Evas_Object *frame;
      Evas_Object *flip;
@@ -22,7 +22,6 @@ typedef struct _Background_Ctx {
      Evas_Object *bubble;
      Evas_Object *op_trans;
      Evas_Object *op_opacity;
-     Evas_Object *op_shine_slider;
 
      Eina_Stringshare *system_path;
      Eina_Stringshare *user_path;
@@ -30,42 +29,19 @@ typedef struct _Background_Ctx {
      Ecore_Timer *bubble_disappear;
 } Background_Ctx;
 
-typedef struct _Background_Item
+typedef struct tag_Background_Item
 {
    const char *path;
    Eina_Bool selected;
    Elm_Object_Item *item;
 } Background_Item;
 
-typedef struct _Insert_Gen_Grid_Item_Notify
+typedef struct tag_Insert_Gen_Grid_Item_Notify
 {
    Elm_Gengrid_Item_Class *class;
    Background_Item *item;
 } Insert_Gen_Grid_Item_Notify;
 
-
-static void
-_cb_op_shine_sel(void *data,
-                 Evas_Object *obj,
-                 void *_event EINA_UNUSED)
-{
-   Background_Ctx *ctx = data;
-   Config *config = ctx->config;
-   Term *term = termio_term_get(ctx->term);
-   Win *wn = term_win_get(term);
-   int shine = elm_slider_value_get(obj);
-   Eina_List *l, *wn_list;
-
-   if (config->shine == shine)
-       return;
-
-   wn_list = win_terms_get(wn);
-   EINA_LIST_FOREACH(wn_list, l, term)
-     {
-        term_apply_shine(term, shine);
-     }
-}
-
 static void
 _cb_op_video_trans_chg(void *data,
                        Evas_Object *obj,
@@ -75,7 +51,6 @@ _cb_op_video_trans_chg(void *data,
    Config *config = ctx->config;
 
    config->translucent = elm_check_state_get(obj);
-   elm_object_disabled_set(ctx->op_opacity, !config->translucent);
    config_save(config);
    main_trans_update();
 }
@@ -89,8 +64,6 @@ _cb_op_video_opacity_chg(void *data,
    Config *config = ctx->config;
 
    config->opacity = elm_slider_value_get(obj);
-   if (!config->translucent)
-     return;
    config_save(config);
    main_trans_update();
 }
@@ -548,7 +521,7 @@ _parent_del_cb(void *data,
 void
 options_background(Evas_Object *opbox, Evas_Object *term)
 {
-   Evas_Object *o, *bx, *bx_front;
+   Evas_Object *o, *bx, *bx_front, *lbl;
    Config *config = termio_config_get(term);
    char path[PATH_MAX];
    Background_Ctx *ctx;
@@ -575,30 +548,6 @@ options_background(Evas_Object *opbox, Evas_Object *term)
    elm_object_content_set(ctx->frame, bx);
    evas_object_show(o);
 
-   o = elm_label_add(opbox);
-   evas_object_size_hint_weight_set(o, 0.0, 0.0);
-   evas_object_size_hint_align_set(o, 0.0, 0.5);
-   elm_object_text_set(o, _("Shine:"));
-   elm_box_pack_end(bx, o);
-   evas_object_show(o);
-
-   ctx->op_shine_slider = o = elm_slider_add(opbox);
-   evas_object_size_hint_weight_set(o, EVAS_HINT_EXPAND, 0.0);
-   evas_object_size_hint_align_set(o, EVAS_HINT_FILL, 0.5);
-   elm_slider_span_size_set(o, 40);
-   elm_slider_unit_format_set(o, "%1.0f");
-   elm_slider_indicator_format_set(o, "%1.0f");
-   elm_slider_min_max_set(o, 0, 255);
-   elm_slider_step_set(o, 1);
-   elm_slider_value_set(o, config->shine);
-   elm_box_pack_end(bx, o);
-   evas_object_show(o);
-
-   evas_object_smart_callback_add(o, "delay,changed",
-                                  _cb_op_shine_sel, ctx);
-
-
-
    ctx->op_trans = o = elm_check_add(opbox);
    evas_object_size_hint_weight_set(o, EVAS_HINT_EXPAND, 0.0);
    evas_object_size_hint_align_set(o, EVAS_HINT_FILL, 0.5);
@@ -609,6 +558,14 @@ options_background(Evas_Object *opbox, Evas_Object *term)
    evas_object_smart_callback_add(o, "changed",
                                   _cb_op_video_trans_chg, ctx);
 
+   OPTIONS_SEPARATOR;
+   lbl = elm_label_add(bx);
+   evas_object_size_hint_weight_set(lbl, EVAS_HINT_EXPAND, 0.0);
+   evas_object_size_hint_align_set(lbl, 0.0, 0.0);
+   elm_layout_text_set(lbl, NULL, _("Opacity:"));
+   elm_box_pack_end(bx, lbl);
+   evas_object_show(lbl);
+
    ctx->op_opacity = o = elm_slider_add(opbox);
    evas_object_size_hint_weight_set(o, EVAS_HINT_EXPAND, 0.0);
    evas_object_size_hint_align_set(o, EVAS_HINT_FILL, 0.5);
@@ -617,7 +574,6 @@ options_background(Evas_Object *opbox, Evas_Object *term)
    elm_slider_indicator_format_set(o, _("%1.0f%%"));
    elm_slider_min_max_set(o, 0, 100);
    elm_slider_value_set(o, config->opacity);
-   elm_object_disabled_set(o, !config->translucent);
    elm_box_pack_end(bx, o);
    evas_object_show(o);
    evas_object_smart_callback_add(o, "changed",
@@ -692,8 +648,6 @@ options_background(Evas_Object *opbox, Evas_Object *term)
    elm_box_pack_end(bx_front, o);
    evas_object_show(o);
 
-
-
    o = elm_fileselector_add(opbox);
    evas_object_size_hint_weight_set(o, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
    evas_object_size_hint_align_set(o, EVAS_HINT_FILL, EVAS_HINT_FILL);
