@@ -1,5 +1,5 @@
-#ifndef _OPTIONS_BACKGROUND_H__
-#define _OPTIONS_BACKGROUND_H__ 1
+#ifndef TERMINOLOGY_OPTIONS_BACKGROUND_H_
+#define TERMINOLOGY_OPTIONS_BACKGROUND_H_ 1
 
 void options_background(Evas_Object *opbox, Evas_Object *term);
 void options_background_clear(void);
