@@ -1,5 +1,5 @@
-#ifndef _PRIVATE_H__
-#define _PRIVATE_H__ 1
+#ifndef TERMINOLOGY_PRIVATE_H_
+#define TERMINOLOGY_PRIVATE_H_ 1
 
 #ifdef HAVE_CONFIG_H
 #include "terminology_config.h"
@@ -62,7 +62,7 @@ extern int _log_domain;
    (!strncmp(STR, STATIC_STR, strlen(STATIC_STR)))
 
 #if !defined(HAVE_STRCHRNUL)
-static inline char *
+static inline const char *
 strchrnul(const char *s, int c)
 {
    const char *p = s;
