@@ -1,5 +1,5 @@
-#ifndef _SB_H__
-#define _SB_H__
+#ifndef TERMINOLOGY_SB_H_
+#define TERMINOLOGY_SB_H_
 
 #include <stddef.h>
 
@@ -11,11 +11,11 @@ struct ty_sb {
 };
 
 int ty_sb_add(struct ty_sb *sb, const char *s, size_t len);
-#define TY_SB_ADD(_SB, _S) ty_sb_add(_SB, _S, strlen(_S))
+#define TY_SB_ADD(SB_, S_) ty_sb_add(SB_, S_, strlen(S_))
 void ty_sb_spaces_rtrim(struct ty_sb *sb);
 void ty_sb_spaces_ltrim(struct ty_sb *sb);
 int ty_sb_prepend(struct ty_sb *sb, const char *s, size_t len);
-#define TY_SB_PREPEND(_SB, _S) ty_sb_prepend(_SB, _S, strlen(_S))
+#define TY_SB_PREPEND(SB_, S_) ty_sb_prepend(SB_, S_, strlen(S_))
 char *ty_sb_steal_buf(struct ty_sb *sb);
 void ty_sb_lskip(struct ty_sb *sb, size_t len);
 void ty_sb_rskip(struct ty_sb *sb, size_t len);
