@@ -9,10 +9,10 @@
 #include "win.h"
 #include "term_container.h"
 
-typedef struct _Sel Sel;
-typedef struct _Entry Entry;
+typedef struct tag_Sel Sel;
+typedef struct tag_Entry Entry;
 
-struct _Sel
+struct tag_Sel
 {
    Evas_Object_Smart_Clipped_Data __clipped_data;
    Evas_Object *self;
@@ -41,7 +41,7 @@ struct _Sel
    unsigned char use_px : 1;
 };
 
-struct _Entry
+struct tag_Entry
 {
    Evas_Object *obj, *bg;
    Term_Container *tc;
@@ -147,7 +147,7 @@ _mouse_move_cb(void *data,
      return;
    iw = sqrt(eina_list_count(sd->items));
    if (iw < 1) iw = 1;
-   ih = (eina_list_count(sd->items) + (iw - 1)) / iw;
+   ih = DIV_ROUND_UP(eina_list_count(sd->items), iw);
    if (ih < 1) ih = 1;
    evas_object_geometry_get(sd->self, &x, &y, &w, &h);
    sw = w * sd->zoom;
@@ -366,7 +366,7 @@ _layout(Sel *sd)
 
    iw = sqrt(eina_list_count(sd->items));
    if (iw < 1) iw = 1;
-   ih = (eina_list_count(sd->items) + (iw - 1)) / iw;
+   ih = DIV_ROUND_UP(eina_list_count(sd->items), iw);
    if (ih < 1) ih = 1;
    evas_object_geometry_get(sd->self, &ox, &oy, &ow, &oh);
    w = ow * sd->zoom;
