@@ -1,13 +1,13 @@
-#ifndef _TERMIOINTERNALS_H__
-#define _TERMIOINTERNALS_H__ 1
+#ifndef TERMINOLOGY_TERMIOINTERNALS_H_
+#define TERMINOLOGY_TERMIOINTERNALS_H_ 1
 
 #if defined(BINARY_TYFUZZ) || defined(BINARY_TYTEST)
 typedef void Term;
 #endif
 
-typedef struct _Termio Termio;
+typedef struct tag_Termio Termio;
 
-struct _Termio
+struct tag_Termio
 {
    Evas_Object_Smart_Clipped_Data __clipped_data;
    struct {
@@ -100,8 +100,8 @@ struct _Termio
    double gesture_zoom_start_size;
 };
 
-typedef struct _Termio_Modifiers Termio_Modifiers;
-struct _Termio_Modifiers
+typedef struct tag_Termio_Modifiers Termio_Modifiers;
+struct tag_Termio_Modifiers
 {
    unsigned char alt              : 1;
    unsigned char shift            : 1;
