@@ -387,13 +387,10 @@ _fd_do(Termpty *ty, Ecore_Fd_Handler *fd_handler, Eina_Bool false_on_empty)
         return ECORE_CALLBACK_CANCEL;
      }
 
-   // it seems the BSDs can not read from this side of the pair if the other side
-   // is closed ... but no longer just bsd's - i have seen this now on linux
+   // it seems one can not read from this side of the pair if the other side
+   // is closed
    if (ty->pid == -1)
-     {
-        ty->hand_fd = NULL;
-        return ECORE_CALLBACK_CANCEL;
-     }
+     return ECORE_CALLBACK_CANCEL;
 
    if (ecore_main_fd_handler_active_get(fd_handler, ECORE_FD_READ))
      {
