@@ -1,5 +1,5 @@
-#ifndef _TERMPTY_EXT_H__
-#define _TERMPTY_EXT_H__ 1
+#ifndef TERMINOLOGY_TERMPTY_EXT_H_
+#define TERMINOLOGY_TERMPTY_EXT_H_ 1
 
 Eina_Bool
 termpty_ext_handle(Termpty *ty,
