@@ -451,6 +451,8 @@ termpty_soft_reset_state(Termpty *ty)
    ty->termstate.cjk_ambiguous_wide = 0;
    ty->termstate.hide_cursor = 0;
    ty->termstate.sace_rectangular = 0;
+   ty->termstate.esc_keycode = 0;
+   ty->termstate.alternate_esc = 0;
    ty->mouse_mode = MOUSE_OFF;
    ty->mouse_ext = MOUSE_EXT_NONE;
    ty->bracketed_paste = 0;
