@@ -1,5 +1,5 @@
-#ifndef _UTF8_H__
-#define _UTF8_H__ 1
+#ifndef TERMINOLOGY_UTF8_H_
+#define TERMINOLOGY_UTF8_H_ 1
 #include <Eina.h>
 int codepoint_to_utf8(Eina_Unicode g, char *txt);
 
