@@ -1,4 +1,6 @@
 #!/bin/sh
+# shellcheck source=tests/utils.sh
+. "$(dirname "$0")/utils.sh"
 
 # fill space with E
 printf '\033[69;1;1;25;80\044x'
@@ -43,4 +45,4 @@ printf '\033[=0c'
 printf '\033[=42c'
 
 # let it print
-sleep 0.2
+test_sleep 0.2
